#!/bin/bash
#PBS -q charon
#PBS -l walltime=92:0:0
#PBS -l select=1:ncpus=5:mem=10gb:scratch_ssd=30gb
#PBS -N p0
#PBS -M martin.lasota@tul.cz
#PBS -m abe

DATADIR=$PBS_O_WORKDIR
ARCHIVE='/storage/du-cesnet/home/martin_lasota/VO_tul_fm_nti-tape_tape'
CASE='07_lopatky/e8f'
I_TIMELEVEL='20000' #flowRegime.input
F_TIMELEVEL='40000'

#----------------------------------#

echo "$PBS_JOBID is running on node `hostname -f` in a scratch directory $SCRATCHDIR" >> $DATADIR/job_node.txt

test -n "SCRATCHDIR" || { echo >&2 "Variable SCRATCHDIR is not set."; exit 1; }

#----------------------------------#

cp -r $DATADIR/$I_TIMELEVEL $SCRATCHDIR || { echo >&2 "Error while copying time levels."; exit 2; }
cp -r $DATADIR/{0,constant,system,*.input,run01_charon.sh} $SCRATCHDIR || { echo >&2 "Error while copying input files."; exit 2; }

: '
for s in {0..19} # nb. of procs
do
	for n in 0.0{1..9}
	do	
	mkdir -p $SCRATCHDIR/processor$s/$n
	cp -r $DATADIR/processor$s/$n/{U.gz,p.gz,meshPhi.gz,cellDisplacement.gz,pointDisplacement.gz,polyMesh,uniform} $SCRATCHDIR/processor$s/$n/
	done

	for n in 0.00{1..9}
	do	
	mkdir -p $SCRATCHDIR/processor$s/$n
	cp -r $DATADIR/processor$s/$n/{U.gz,p.gz,meshPhi.gz,cellDisplacement.gz,pointDisplacement.gz,polyMesh,uniform} $SCRATCHDIR/processor$s/$n/
	done

	for n in 0.000{1..9}
	do	
	mkdir -p $SCRATCHDIR/processor$s/$n
	cp -r $DATADIR/processor$s/$n/{U.gz,p.gz,meshPhi.gz,cellDisplacement.gz,pointDisplacement.gz,polyMesh,uniform} $SCRATCHDIR/processor$s/$n/
	done
	
	for n in 0.{1..2000} # nb. of time levels
	do
	mkdir -p $SCRATCHDIR/processor$s/$n
	cp -r $DATADIR/processor$s/$n/{U.gz,p.gz,meshPhi.gz,cellDisplacement.gz,pointDisplacement.gz,polyMesh,uniform} $SCRATCHDIR/processor$s/$n/

	done	
done
'

#----------------------------------#

cd $SCRATCHDIR

source $HOME/OpenFOAM/OpenFOAM-6L/nacist.sh

export LD_LIBRARY_PATH=$HOME/OpenFOAM/martin_lasota-6L/platforms/linux64IccDPInt32Opt/lib:$LD_LIBRARY_PATH

. $WM_PROJECT_DIR/bin/tools/RunFunctions
application="$(getApplication)"

#runApplication transformPoints -scale "(1 0 1)"

runApplication decomposePar -time $I_TIMELEVEL
cat log.decomposePar >> log.decomposePar-archiv
rm log.decomposePar

runParallel $application
cat log.$application >> log.$application-archiv
rm log.$application

reconstructPar -time $F_TIMELEVEL >> log.reconstructPar-archiv

#postProcess -func "flowRatePatch(name=Gin)" -time 0.16:0.20

#foamToEnsight -noPatches

cp /storage/liberec3-tul/home/martin_lasota/astra/07_lopatky/e10h/system/sampleDict system/
rhoSimpleFoam -postProcess -func sampleDict -time $F_TIMELEVEL

#----------------------------------#

#cp -r $SCRATCHDIR/{EnSight,postProcessing} $DATADIR || { echo >&2 "Result files copying failed (with a code $?)."; exit 4; }

cp -r $SCRATCHDIR/{$F_TIMELEVEL,postProcessing,log.*} $DATADIR || { echo >&2 "Result files copying failed (with a code $?)."; exit 4; }

#mkdir -p $ARCHIVE/$CASE
#mv $SCRATCHDIR/* $ARCHIVE/$CASE || { echo >&2 "Result files copying failed (with a code $?)."; exit 4; }

#----------------------------------#


